summaryrefslogtreecommitdiffstats
path: root/noatun/modules/kjofol-skin/kjbutton.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
commitf59dfa08651a47f21d004e8e4cb5020b8035287e (patch)
tree0582273566661474af14fe8f1737cfe1e6527d46 /noatun/modules/kjofol-skin/kjbutton.cpp
parent83fbc82a101309e171089f0d5ed080f82a367345 (diff)
downloadtdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.tar.gz
tdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 83fbc82a101309e171089f0d5ed080f82a367345.
Diffstat (limited to 'noatun/modules/kjofol-skin/kjbutton.cpp')
-rw-r--r--noatun/modules/kjofol-skin/kjbutton.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/noatun/modules/kjofol-skin/kjbutton.cpp b/noatun/modules/kjofol-skin/kjbutton.cpp
index 795dedfb..edd53e2b 100644
--- a/noatun/modules/kjofol-skin/kjbutton.cpp
+++ b/noatun/modules/kjofol-skin/kjbutton.cpp
@@ -165,9 +165,9 @@ void KJButton::showPressed(bool b)
{
mShowPressed = b;
if ( mShowPressed )
- repaint(true); // repaint with selected image
+ tqrepaint(true); // tqrepaint with selected image
else
- repaint(false); // repaint with default image (player-background)
+ tqrepaint(false); // tqrepaint with default image (player-background)
}
void KJButton::slotPlaylistShown(void)
@@ -193,8 +193,8 @@ void KJButton::slotEqEnabled(bool on)
void KJButton::mouseRelease(const TQPoint &, bool in)
{
- // repaint with default image (player-background)
- repaint(false);
+ // tqrepaint with default image (player-background)
+ tqrepaint(false);
if (!in) // only do something if users is still inside the button
return;